==> tine20-allinone_2020.03.4.tar.bz2: Crm/js/Crm-lang-pt_BR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-12-04 15:50+0000\nLast-Translator: fgsl <flavio.lisboa@serpro.gov.br>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nLanguage: pt_BR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "All leads"
: "Todos os líderes"

, "Default Lead List"
: "Lista Básica de Líderes"

, "The default list for new leads"
: "Lista básica para novos líderes"

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: "Lista de ações que você quer ser notificado sobre."

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Send Notifications e-mails to responsible"
: ""

, "Get notifications e-mails for action to responsible"
: ""

, "Send Notifications e-mails to customer"
: ""

, "Get notifications e-mails for action to customer"
: ""

, "Send Notifications e-mails to partner"
: ""

, "Get notifications e-mails for action to partner"
: ""

, "Default Favorite"
: "Favorito Padrão"

, "The default favorite which is loaded on crm startup"
: "O principal favorito que é carregado no início do crm"

, "New Lead"
: "Novo Lider"

, "Tags"
: "Marcadores"

, "Lead name"
: "Nome Principal"

, "Responsible"
: "Responsável"

, "Partner"
: "Parceiro"

, "Customer"
: "Cliente"

, "Leadstate"
: "Estado da Liderança"

, "Leadtype"
: "Tipo da Liderança"

, "Leadsource"
: "Fonte da Liderança"

, "Probability"
: "Probabilidade"

, "Turnover"
: "Volume de Negócios"

, "Estimated end"
: "Fim Estimado"

, "Probable Turnover"
: "Volume Provável de Negócios"

, "Resubmission Date"
: "Data de Re-submissão"

, "Import leads"
: "Importar dianteiras"

, "Contact"
: "Contato"

, "CRM Role"
: "Perfil de CRM"

, "Tasks"
: "Tarefas"

, "No Tasks to display"
: "Nenhuma tarefa para exibir"

, "Summary"
: "Sumário"

, "Add a task..."
: "Adicionar uma tarefa..."

, "Due Date"
: "Data de Vencimento"

, "Priority"
: "Prioridade"

, "Percent"
: "Percentual"

, "Status"
: "Status"

, "Organizer"
: "Organizador"

, "Add new {0}"
: "Adicionar novo {0}"

, "Unlink {0}"
: "Desconectados {0}"

, "Unlink selected {0}"
: "Desconectados selecionados {0}"

, "Edit {0}"
: "Editar {0}"

, "Edit selected {0}"
: "Editar selecionados {0}"

, "Please choose the Lead to add the contacts to"
: "Selecione o Lider para adicionar contatos"

, "Please select the attenders' role"
: "Selecione o perfil dos frequentadores"

, "Lead, Leads"
: [
  "Liderança"
 ,"Lideranças"

]
, "Select Lead"
: "Selecione a Liderança"

, "Role"
: "Função"

, "Select Role"
: "Selecione a Função"

, "Adding {0} contacts to lead"
: "Adicionando {0} contatos à liderança"

, "Phone"
: "Telefone"

, "Mobile"
: "Celular"

, "Fax"
: "Fax"

, "E-Mail"
: "Email"

, "Web"
: "Web"

, "Street"
: "Rua"

, "Postalcode"
: "CEP"

, "City"
: "Cidade"

, "Start"
: "Iniciar"

, "Change type to Customer"
: "Troque o tipo de Cliente"

, "Change type to Responsible"
: "Troque o tipo de Responsável"

, "Change type to Partner"
: "Troque o tipo de Parceiro"

, "Change contact type"
: "Troque o tipo de contato"

, "Search for Contacts to add ..."
: "Pesquisar Contatos para adicionar ..."

, "Name"
: "Nome"

, "Address"
: "Endereço"

, "Data"
: "Informação"

, "Cellphone"
: "Celular"

, "End"
: "Fim"

, "You do not have the run right for the Tasks application or it is not activated."
: "Você não possui privilégio para executar a aplicação de Tarefa ou não está "

, "Products"
: "Produtos"

, "You do not have the run right for the Sales application or it is not activated."
: "Você não possui privilégio para executar a aplicação de Vendas ou não está "

, "Enter lead name"
: "Entrar com nome dianteiro"

, "Expected turnover"
: "Volume esperado de negócios"

, "Description"
: "Descrição"

, "Enter description"
: "Insira a descrição"

, "lead list, lead lists"
: [
  "lista de líder"
 ,"listas de líderes"

]
, "lead lists"
: "listas de líderes"

, "Quick Search"
: "Busca Rápida"

, "Last Modified Time"
: "Hora da Última Modificação"

, "Last Modified By"
: "Modificado recentemente por"

, "Creation Time"
: "Hora de Criação"

, "Created By"
: "Criado por"

, "X Lead"
: "X Dianteiro"

, "Archived"
: "Arquivado"

, "Product"
: "Produto"

, "Price"
: "Preço"

, "Quantity"
: "Quantidade"

, "Search for Products to add ..."
: "Pesquisar Produtos para adicionar ..."

, "All leads I have read grants for"
: "Todos os líderes que eu concedi leitura para"

, "Last modified by me"
: "Modificado recentemente por mim"

, "All leads that I have last modified"
: "Todos os líderes que eu modfiquei recentemente"

, "My leads"
: "Meus líderes"

, "All leads that I am responsible for"
: "Todos os líderes por quem sou responsável"

, "Leads with overdue tasks"
: "Líderes com tarefas atrasadas"

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "abrir"

, "contacted"
: "contatado"

, "waiting for feedback"
: "Aguardando retorno"

, "quote sent"
: "orçamento enviado"

, "accepted"
: "aceito"

, "lost"
: "perdido"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "Revendedor"

, "Enabled Features"
: ""

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "State"
: "Estado"

, "Source"
: "Fonte"

, "Scheduled end"
: "Fim do Programado"

, "Folder"
: "Pasta"

, "Updated by"
: "Atualizado por"

, "Updated Fields:"
: "Campos atualizados:"

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: "Liderança %s foi modificada"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: "Liderança %s foi criada"

, "Task"
: ""

, "Lead Data"
: "Dado da Liderança"

, "End Scheduled"
: "Fim do Plano"

, "Contacts"
: "Contatos"

, "Telephone"
: "Telefone"

, "Email"
: "Email"

, "low"
: "baixo"

, "normal"
: "normal"

, "high"
: "alto"

, "urgent"
: "urgente"

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "manage shared lead folders"
: "administrar pastas de lideranças compartilhadas"

, "Create new shared lead folders"
: "Criar novas pastas de lideranças compartilhadas"

, "manage shared leads favorites"
: "gerenciar as principais lideranças favoritas compartilhadas"

, "Create or update shared leads favorites"
: "Criar ou atualizar lideranças favoritas compartilhadas"




, "Lead"
: "Liderança"

, "lead list"
: "lista de líder"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Crm/js/Crm-lang-pt_BR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:49+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nLanguage: pt_BR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Customer"
: "Cliente"

, "Partner"
: "Parceiro"

, "Phone"
: "Telefone"

, "Mobile"
: "Celular"

, "Fax"
: "Fax"

, "E-Mail"
: "Email"

, "Web"
: "Web"

, "Street"
: "Rua"

, "Postalcode"
: "CEP"

, "City"
: "Cidade"

, "Status"
: "Status"

, "Start"
: "Iniciar"

, "Estimated end"
: "Fim Estimado"

, "Leadtype"
: "Tipo da Liderança"

, "Leadsource"
: "Fonte da Liderança"

, "Tags"
: "Marcadores"

, "Lead name"
: "Nome Principal"

, "Responsible"
: "Responsável"

, "Leadstate"
: "Estado da Liderança"

, "Probability"
: "Probabilidade"

, "Turnover"
: "Volume de Negócios"

, "End"
: "Fim"

, "Probable Turnover"
: "Volume Provável de Negócios"

, "Resubmission Date"
: "Data de Re-submissão"

, "Import leads"
: "Importar dianteiras"

, "Add new {0}"
: "Adicionar novo {0}"

, "Unlink {0}"
: "Desconectados {0}"

, "Unlink selected {0}"
: "Desconectados selecionados {0}"

, "Edit {0}"
: "Editar {0}"

, "Edit selected {0}"
: "Editar selecionados {0}"

, "New Lead"
: "Novo Lider"

, "Products"
: "Produtos"

, "Product"
: "Produto"

, "Description"
: "Descrição"

, "Price"
: "Preço"

, "Quantity"
: "Quantidade"

, "Search for Products to add ..."
: "Pesquisar Produtos para adicionar ..."

, "1"
: ""

, "Notifications are disabled"
: ""

, "Send Notification?"
: ""

, "Changes to this lead might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
: ""

, "Tasks"
: "Tarefas"

, "You do not have the run right for the Tasks application or it is not activated."
: "Você não possui privilégio para executar a aplicação de Tarefa ou não está "

, "You do not have the run right for the Sales application or it is not activated."
: "Você não possui privilégio para executar a aplicação de Vendas ou não está "

, "Lead, Leads"
: [
  "Liderança"
 ,"Lideranças"

]
, "Enter lead name"
: "Entrar com nome dianteiro"

, "Expected turnover"
: "Volume esperado de negócios"

, "Enter description"
: "Insira a descrição"

, "lead list, lead lists"
: [
  "lista de líder"
 ,"listas de líderes"

]
, "lead lists"
: "listas de líderes"

, "Quick Search"
: "Busca Rápida"

, "Last Modified Time"
: "Hora da Última Modificação"

, "Last Modified By"
: "Modificado recentemente por"

, "Creation Time"
: "Hora de Criação"

, "Created By"
: "Criado por"

, "X Lead"
: "X Dianteiro"

, "read-only"
: ""

, "Archived"
: "Arquivado"

, "Contact"
: "Contato"

, "CRM Role"
: "Perfil de CRM"

, "Change type to Customer"
: "Troque o tipo de Cliente"

, "Change type to Responsible"
: "Troque o tipo de Responsável"

, "Change type to Partner"
: "Troque o tipo de Parceiro"

, "Change contact type"
: "Troque o tipo de contato"

, "Search for Contacts to add ..."
: "Pesquisar Contatos para adicionar ..."

, "Name"
: "Nome"

, "Address"
: "Endereço"

, "Data"
: "Informação"

, "Cellphone"
: "Celular"

, "Role"
: "Função"

, "Please choose the Lead to add the contacts to"
: "Selecione o Lider para adicionar contatos"

, "Please select the attenders' role"
: "Selecione o perfil dos frequentadores"

, "Select Lead"
: "Selecione a Liderança"

, "Select Role"
: "Selecione a Função"

, "Adding {0} contacts to lead"
: "Adicionando {0} contatos à liderança"

, "No Tasks to display"
: "Nenhuma tarefa para exibir"

, "Summary"
: "Sumário"

, "Add a task..."
: "Adicionar uma tarefa..."

, "Due Date"
: "Data de Vencimento"

, "Priority"
: "Prioridade"

, "Percent"
: "Percentual"

, "Organizer"
: "Organizador"

, "All leads"
: "Todos os líderes"

, "Default Lead List"
: "Lista Básica de Líderes"

, "The default list for new leads"
: "Lista básica para novos líderes"

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: "Lista de ações que você quer ser notificado sobre."

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Default Favorite"
: "Favorito Padrão"

, "The default favorite which is loaded on crm startup"
: "O principal favorito que é carregado no início do crm"

, "controls sending notification of Leads"
: ""

, "send notification)description"
: ""

, "send notification to all access container"
: ""

, "send notification to responsible"
: ""

, "send notification to responsible)description"
: ""

, "send notification to customer"
: ""

, "send notification to partner"
: ""

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "abrir"

, "contacted"
: "contatado"

, "waiting for feedback"
: "Aguardando retorno"

, "quote sent"
: "orçamento enviado"

, "accepted"
: "aceito"

, "lost"
: "perdido"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "Revendedor"

, "Enabled Features"
: ""

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Lead Notification Confirmation"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Lead Data"
: "Dado da Liderança"

, "End Scheduled"
: "Fim do Plano"

, "Contacts"
: "Contatos"

, "Telephone"
: "Telefone"

, "Email"
: "Email"

, "low"
: "baixo"

, "normal"
: "normal"

, "high"
: "alto"

, "urgent"
: "urgente"

, "CSV all data"
: ""

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "GENDER_Lead"
: ""

, "Show Closed"
: ""

, "Task"
: ""

, "State"
: "Estado"

, "Source"
: "Fonte"

, "Scheduled end"
: "Fim do Programado"

, "Folder"
: "Pasta"

, "Updated by"
: "Atualizado por"

, "Updated Fields:"
: "Campos atualizados:"

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: "Liderança %s foi modificada"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: "Liderança %s foi criada"

, "This Lead state is set to read-only therefore updating this Lead is not possible."
: ""

, "All leads I have read grants for"
: "Todos os líderes que eu concedi leitura para"

, "Last modified by me"
: "Modificado recentemente por mim"

, "All leads that I have last modified"
: "Todos os líderes que eu modfiquei recentemente"

, "My leads"
: "Meus líderes"

, "All leads that I am responsible for"
: "Todos os líderes por quem sou responsável"

, "Leads with overdue tasks"
: "Líderes com tarefas atrasadas"

, "manage shared lead folders"
: "administrar pastas de lideranças compartilhadas"

, "Create new shared lead folders"
: "Criar novas pastas de lideranças compartilhadas"

, "manage shared leads favorites"
: "gerenciar as principais lideranças favoritas compartilhadas"

, "Create or update shared leads favorites"
: "Criar ou atualizar lideranças favoritas compartilhadas"




, "Lead"
: "Liderança"

, "lead list"
: "lista de líder"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
